@@ -127,11 +127,15 @@ formatting = {
             'detailedWhereAmI' : 'pageSummary'
             },
         pyatspi.ROLE_ALERT: {
-            'unfocused': 'labelOrName + roleName + pause + (expandedEOCs or unrelatedLabels)'
+            'unfocused': 'labelOrName + roleName + pause + (expandedEOCs or unrelatedLabels or description)'
             },
         pyatspi.ROLE_ANIMATION: {
             'unfocused': 'labelAndName'
             },
+        pyatspi.ROLE_ARTICLE: {
+            'focused': 'labelOrName + roleName',
+            'unfocused': 'labelOrName + roleName + pause + currentLineText + allTextSelection',
+            },
         pyatspi.ROLE_BLOCK_QUOTE: {
             'focused' : 'leaving or (roleName + pause + nestingLevel)',
             'unfocused': 'roleName + pause + nestingLevel + pause + displayedText',
@@ -168,20 +172,32 @@ formatting = {
             'unfocused': 'labelAndName + roleName + pause + (currentLineText + anyTextSelection or positionInList) + ' + MNEMONIC + ' + accelerator',
             'basicWhereAmI': 'label + roleName + pause + name + (currentLineText + anyTextSelection or positionInList) + ' + MNEMONIC + ' + accelerator'
             },
+        pyatspi.ROLE_COMMENT: {
+            'focused': 'labelOrName + roleName',
+            'unfocused': 'labelOrName + roleName + pause + currentLineText + allTextSelection',
+            },
         pyatspi.ROLE_DIAL: {
             'focused': 'value',
             'unfocused': 'labelOrName + roleName + value + required + availability + ' + MNEMONIC,
             'basicWhereAmI': 'labelOrName + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
             },
         pyatspi.ROLE_DIALOG: {
-            'focused': 'labelOrName + roleName',
-            'unfocused': 'expandedEOCs or (labelOrName + unrelatedLabels)'
+            'focused': 'labelOrName + roleName + description',
+            'unfocused': 'expandedEOCs or (labelOrName + (unrelatedLabels or description))'
             },
         pyatspi.ROLE_DOCUMENT_FRAME: {
             'unfocused': 'label + readOnly + textRole + currentLineText + anyTextSelection + ' + MNEMONIC,
             'basicWhereAmI': 'label + readOnly + textRole + textContent + anyTextSelection + ' + MNEMONIC,
             'detailedWhereAmI': 'label + readOnly + textRole + textContentWithAttributes + anyTextSelection + ' + MNEMONIC
             },
+        'ROLE_DPUB_LANDMARK': {
+            'focused': 'leaving or labelOrName',
+            'unfocused': 'labelOrName + currentLineText + allTextSelection'
+            },
+        'ROLE_DPUB_SECTION': {
+            'focused': 'leaving or (labelOrName + roleName)',
+            'unfocused': 'labelOrName + currentLineText + allTextSelection'
+            },
         pyatspi.ROLE_EMBEDDED: {
             'focused': 'labelOrName + roleName',
             'unfocused': '(expandedEOCs or (labelOrName + unrelatedLabels)) + roleName'
@@ -192,6 +208,9 @@ formatting = {
             'basicWhereAmI': 'labelOrName + readOnly + textRole + (textContent or placeholderText) + anyTextSelection + required + pause + invalid + ' + MNEMONIC,
             'detailedWhereAmI': 'labelOrName + readOnly + textRole + (textContentWithAttributes or placeholderText) + anyTextSelection + required + pause + invalid + ' + MNEMONIC,
             },
+        'ROLE_FOOTNOTE': {
+            'unfocused': 'labelOrName + roleName + pause + currentLineText + allTextSelection',
+            },
         pyatspi.ROLE_FOOTER: {
             'unfocused': '(displayedText or name) + roleName',
         },
@@ -267,13 +286,10 @@ formatting = {
         'ROLE_MATH_FENCED': {
             'unfocused': 'fencedStart + pause + fencedContents + pause + fencedEnd',
         },
-        # TODO - JD: When we bump dependencies to 2.16, remove this fake role and use the real one.
-        'ROLE_MATH_FRACTION': {
+        pyatspi.ROLE_MATH_FRACTION: {
             'unfocused': 'fractionStart + pause + fractionNumerator + fractionLine + fractionDenominator + pause + fractionEnd + pause',
         },
-        # TODO - JD: When we bump dependencies to 2.16, remove this fake role and use the real one
-        # (assuming, of course, we've solved the square root/nth root identification problem too).
-        'ROLE_MATH_ROOT': {
+        pyatspi.ROLE_MATH_ROOT: {
             'unfocused': 'rootStart + rootBase + pause + rootEnd + pause',
         },
         # TODO - JD: When we bump dependencies to TBD, remove this fake role and use the real one.
@@ -389,10 +405,7 @@ formatting = {
             'unfocused': 'labelAndName + roleName + value + availability + ' + MNEMONIC,
             'basicWhereAmI' : 'labelAndName + roleName + value'
             },
-        # TODO - JD: There is now an actual ROLE_STATIC in ATK and AT-SPI2. Next
-        # time we need to bump dependencies for more significant things, we need
-        # to remove this fake role and use it instead.
-        'ROLE_STATIC': {
+        pyatspi.ROLE_STATIC: {
             'unfocused': '(displayedText or name) + roleName',
         },
         'ROLE_SWITCH': {
@@ -517,6 +530,11 @@ formatting = {
             'unfocused': '[Component(obj,\
                                      asString(label + displayedText + roleName + (description and space(": ") + description)))]',
             },
+        pyatspi.ROLE_ARTICLE: {
+            'unfocused': '((substring and ' + BRAILLE_TEXT + ')\
+                          or ([Component(obj, asString(labelAndName + roleName))]\
+                             + (childWidget and ([Region(" ")] + childWidget))))'
+            },
         #pyatspi.ROLE_ARROW: 'default'
         pyatspi.ROLE_CANVAS: {
             'unfocused': '[Component(obj,\
@@ -896,10 +914,10 @@ class Formatting(dict):
                      and isinstance(val, str):
                     self[key] = val
                 else:
-                    # exception or such like, we are trying to murge
+                    # exception or such like, we are trying to merge
                     # incompatible trees.
                     # throw an exception?
-                    print("an error has occured, cant murge dicts.")
+                    print("an error has occurred, cant merge dicts.")
             else:
                 self[key] = val
 
